@@ -950,7 +950,22 @@ sub check_prereq {
     my $self   = shift;
     my $result = $self->SUPER::check_prereq(@_);
     unless ($result) {
-	$self->log_warn(<<END);
+	my $bioperl_present = eval "use Bio::Root::Version 1.0069; 1";
+	if (!$bioperl_present) {
+	    $self->log_warn(<<END);
+  * This module requires Bioperl 1.62 or higher, which may not be available       *
+  * on CPAN. Please obtain the latest development version from                    *
+  * http://github.com/bioperl/bioperl-live/tarball/master                         *
+  * To download from the command line, and install run:                           *
+  *  wget --no-check-certificate http://github.com/bioperl/bioperl-live/tarball/master -O bioperl.tar.gz *
+  *  tar zxvf bioperl.tar.gz                                                      *
+  *  cd bioperl*                                                                  *
+  *  perl Build.PL                                                                *
+  *  sudo Build install                                                           *
+
+END
+	} else {
+	    $self->log_warn(<<END);
   * Do not worry if some "recommended" prerequisites are missing. You can install *
   * them later if you need the features they provide. Do not proceed with the     *
   * install if any of "REQUIRED" prerequisites are missing.                       *
@@ -960,6 +975,7 @@ sub check_prereq {
 
 END
     }
+    }
 }
 
 1;
