@@ -18,6 +18,7 @@ use CGI 'pre';
 my %CONFIG_CACHE; # cache parsed config files
 my %DB_SETTINGS;  # cache database settings
 my %LOADED_GLYPHS;
+my $SQLITE_FIXED;
 
 BEGIN {
     if( $ENV{MOD_PERL} &&
@@ -351,6 +352,14 @@ sub too_many_landmarks { shift->global_setting('too many landmarks') || 100 }
 
 sub plugins          { shellwords(shift->global_setting('plugins'))      }
 
+sub remote_renderer {
+    my $self  = shift;
+    my $label = shift;
+    my $url   = $self->fallback_setting($label => 'remote renderer');
+    return $url if defined $url;
+    return $self->global_setting('remote renderer');
+}
+
 
 sub labels {
   my $self   = shift;
@@ -927,6 +936,7 @@ sub open_database {
 
   my ($dbid,$adaptor,@argv) = $self->db_settings($track,$length);
   my $db                    = Bio::Graphics::Browser2::DataBase->open_database($adaptor,@argv);
+  $self->fix_sqlite if $adaptor eq 'Bio::DB::SeqFeature::Store' && "@argv" =~ /SQLite/;  # work around broken bioperl
   
   # do a little extra stuff the first time we see a new database
   unless ($self->{databases_seen}{$db}++) {
@@ -1265,5 +1275,11 @@ sub subtrack_scan_list {
     return \@ids;
 }
 
+sub fix_sqlite {
+    return if $SQLITE_FIXED++;
+    no warnings;
+    *Bio::DB::SeqFeature::Store::DBI::SQLite::_has_spatial_index = sub { return };
+}
+
 1;
 
