@@ -1,6 +1,6 @@
 package Bio::Graphics::Browser2::UserTracks;
 
-# $Id: UserTracks.pm 24441 2011-01-29 16:03:07Z lstein $
+# $Id: UserTracks.pm 24758 2011-04-01 15:05:22Z lstein $
 use strict;
 use Bio::Graphics::Browser2::DataSource;
 use Bio::Graphics::Browser2::DataLoader;
@@ -168,7 +168,8 @@ sub path {
     my $self = shift;
     my $uploadsid = $self->uploadsid;
     my $source    = $self->data_source;
-    return $self->is_admin ? $source->admindata() : $source->userdata($uploadsid);
+    my $path = $self->is_admin ? $source->admindata() : $source->userdata($uploadsid);
+    return $path;
 }
 
 # Track Path (File) - Returns a verified path to the folder holding a track.
@@ -498,15 +499,18 @@ sub upload_file {
     my $self = shift;
     my ($file_name, $fh, $content_type, $overwrite) = @_;
 
+    my $original_name = $file_name;
+    $file_name    =~ s/\.(gz|bz2)$//;  # to indicate that it is decompressed
+
     warn "$file_name: OVERWRITE = $overwrite" if DEBUG;
 
     my $filename = $self->trackname_from_url($file_name, !$overwrite);
     
     $content_type ||= '';
 
-    if ($content_type eq 'application/gzip' or $file_name =~ /\.gz$/) {
+    if ($content_type eq 'application/gzip' or $original_name =~ /\.gz$/) {
 		$fh = $self->install_filter($fh,'gunzip -c');
-    } elsif ($content_type eq 'application/bzip2' or $file_name =~ /\.bz2$/) {
+    } elsif ($content_type eq 'application/bzip2' or $original_name =~ /\.bz2$/) {
 		$fh = $self->install_filter($fh,'bunzip2 -c');
     }
     
@@ -747,6 +751,7 @@ sub install_filter {
     return $out_fh if $child;
 
     # we are in child now
+    Bio::Graphics::Browser2::Render->prepare_fcgi_for_fork('child');
     my $unzip = IO::File->new("| $command") or die "Can't open $command: $!";
     my $buffer;
     while ((my $bytes = read($in_fh,$buffer,8192))>0) {
